@@ -415,6 +415,10 @@ class KubeModel(ABC):
                     loss += self.train(batch, idx)
                     # self.logger.debug(f'loss is {loss}, iterations are {num_iterations}')
 
+                    # update model and parameter
+                    loss.backward()
+                    self.optimizer.step()
+
                 self._on_iteration_end()
             except RedisError as re:
                 raise StorageError(re)
